@@ -3,7 +3,7 @@ package DateTime::Locale::Catalog;
 use strict;
 use warnings;
 
-our $VERSION = '1.10';
+our $VERSION = '1.16';
 
 1;
 
@@ -21,7 +21,7 @@ DateTime::Locale::Catalog - Provides a catalog of all valid locale names
 
 =head1 VERSION
 
-version 1.10
+version 1.16
 
 =head1 DESCRIPTION
 
@@ -94,9 +94,9 @@ The available locales are:
  ast              Asturian                                  asturianu
  ast-ES           Asturian Spain                            asturianu España
  az               Azerbaijani                               azərbaycan
- az-Cyrl          Azerbaijani                               азәрбајҹан
+ az-Cyrl          Azerbaijani Cyrillic                      азәрбајҹан Кирил
  az-Cyrl-AZ       Azerbaijani Azerbaijan Cyrillic           азәрбајҹан Азәрбајҹан Кирил
- az-Latn          Azerbaijani                               azərbaycan
+ az-Latn          Azerbaijani Latin                         azərbaycan latın
  az-Latn-AZ       Azerbaijani Azerbaijan Latin              azərbaycan Azərbaycan latın
  bas              Basaa                                     Ɓàsàa
  bas-CM           Basaa Cameroon                            Ɓàsàa Kàmɛ̀rûn
@@ -121,9 +121,9 @@ The available locales are:
  brx              Bodo                                      बड़ो
  brx-IN           Bodo India                                बड़ो भारत
  bs               Bosnian                                   bosanski
- bs-Cyrl          Bosnian                                   босански
+ bs-Cyrl          Bosnian Cyrillic                          босански Ћирилица
  bs-Cyrl-BA       Bosnian Bosnia & Herzegovina Cyrillic     босански Босна и Херцеговина Ћирилица
- bs-Latn          Bosnian                                   bosanski
+ bs-Latn          Bosnian Latin                             bosanski latinica
  bs-Latn-BA       Bosnian Bosnia & Herzegovina Latin        bosanski Bosna i Hercegovina latinica
  ca               Catalan                                   català
  ca-AD            Catalan Andorra                           català Andorra
@@ -141,7 +141,7 @@ The available locales are:
  ckb-IQ           Central Kurdish Iraq                      کوردیی ناوەندی عێراق
  ckb-IR           Central Kurdish Iran                      کوردیی ناوەندی ئێران
  cs               Czech                                     čeština
- cs-CZ            Czech Czech Republic                      čeština Česká republika
+ cs-CZ            Czech Czechia                             čeština Česko
  cu               Church Slavic                             cu
  cu-RU            Church Slavic Russia                      cu RU
  cy               Welsh                                     Cymraeg
@@ -290,6 +290,7 @@ The available locales are:
  es-AR            Spanish Argentina                         español Argentina
  es-BO            Spanish Bolivia                           español Bolivia
  es-BR            Spanish Brazil                            español Brasil
+ es-BZ            Spanish Belize                            español Belice
  es-CL            Spanish Chile                             español Chile
  es-CO            Spanish Colombia                          español Colombia
  es-CR            Spanish Costa Rica                        español Costa Rica
@@ -432,6 +433,7 @@ The available locales are:
  it-CH            Italian Switzerland                       italiano Svizzera
  it-IT            Italian Italy                             italiano Italia
  it-SM            Italian San Marino                        italiano San Marino
+ it-VA            Italian Vatican City                      italiano Città del Vaticano
  ja               Japanese                                  日本語
  ja-JP            Japanese Japan                            日本語 日本
  jgo              Ngomba                                    Ndaꞌa
@@ -539,7 +541,7 @@ The available locales are:
  mua              Mundang                                   MUNDAŊ
  mua-CM           Mundang Cameroon                          MUNDAŊ kameruŋ
  my               Burmese                                   မြန်မာ
- my-MM            Burmese Myanmar (Burma)                   မြန်မာ မြန်မာ (Burma)
+ my-MM            Burmese Myanmar (Burma)                   မြန်မာ မြန်မာ
  mzn              Mazanderani                               مازرونی
  mzn-IR           Mazanderani Iran                          مازرونی ایران
  naq              Nama                                      Khoekhoegowab
@@ -582,9 +584,9 @@ The available locales are:
  os-GE            Ossetic Georgia                           ирон Гуырдзыстон
  os-RU            Ossetic Russia                            ирон Уӕрӕсе
  pa               Punjabi                                   ਪੰਜਾਬੀ
- pa-Arab          Punjabi                                   پنجابی
+ pa-Arab          Punjabi Arabic                            پنجابی عربی
  pa-Arab-PK       Punjabi Pakistan Arabic                   پنجابی پاکستان عربی
- pa-Guru          Punjabi                                   ਪੰਜਾਬੀ
+ pa-Guru          Punjabi Gurmukhi                          ਪੰਜਾਬੀ ਗੁਰਮੁਖੀ
  pa-Guru-IN       Punjabi India Gurmukhi                    ਪੰਜਾਬੀ ਭਾਰਤ ਗੁਰਮੁਖੀ
  pl               Polish                                    polski
  pl-PL            Polish Poland                             polski Polska
@@ -647,9 +649,9 @@ The available locales are:
  sg               Sango                                     Sängö
  sg-CF            Sango Central African Republic            Sängö Ködörösêse tî Bêafrîka
  shi              Tachelhit                                 ⵜⴰⵛⵍⵃⵉⵜ
- shi-Latn         Tachelhit                                 Tashelḥiyt
+ shi-Latn         Tachelhit Latin                           Tashelḥiyt Latn
  shi-Latn-MA      Tachelhit Morocco Latin                   Tashelḥiyt lmɣrib Latn
- shi-Tfng         Tachelhit                                 ⵜⴰⵛⵍⵃⵉⵜ
+ shi-Tfng         Tachelhit Tifinagh                        ⵜⴰⵛⵍⵃⵉⵜ Tfng
  shi-Tfng-MA      Tachelhit Morocco Tifinagh                ⵜⴰⵛⵍⵃⵉⵜ ⵍⵎⵖⵔⵉⴱ Tfng
  si               Sinhala                                   සිංහල
  si-LK            Sinhala Sri Lanka                         සිංහල ශ්‍රී ලංකාව
@@ -671,12 +673,12 @@ The available locales are:
  sq-MK            Albanian Macedonia                        shqip Maqedoni
  sq-XK            Albanian Kosovo                           shqip Kosovë
  sr               Serbian                                   српски
- sr-Cyrl          Serbian                                   српски
+ sr-Cyrl          Serbian Cyrillic                          српски ћирилица
  sr-Cyrl-BA       Serbian Bosnia & Herzegovina Cyrillic     српски Босна и Херцеговина ћирилица
  sr-Cyrl-ME       Serbian Montenegro Cyrillic               српски Црна Гора ћирилица
  sr-Cyrl-RS       Serbian Serbia Cyrillic                   српски Србија ћирилица
  sr-Cyrl-XK       Serbian Kosovo Cyrillic                   српски Косово ћирилица
- sr-Latn          Serbian                                   srpski
+ sr-Latn          Serbian Latin                             srpski latinica
  sr-Latn-BA       Serbian Bosnia & Herzegovina Latin        srpski Bosna i Hercegovina latinica
  sr-Latn-ME       Serbian Montenegro Latin                  srpski Crna Gora latinica
  sr-Latn-RS       Serbian Serbia Latin                      srpski Srbija latinica
@@ -724,16 +726,16 @@ The available locales are:
  ur-IN            Urdu India                                اردو بھارت
  ur-PK            Urdu Pakistan                             اردو پاکستان
  uz               Uzbek                                     o‘zbek
- uz-Arab          Uzbek                                     اوزبیک
+ uz-Arab          Uzbek Arabic                              اوزبیک عربی
  uz-Arab-AF       Uzbek Afghanistan Arabic                  اوزبیک افغانستان عربی
- uz-Cyrl          Uzbek                                     ўзбекча
+ uz-Cyrl          Uzbek Cyrillic                            ўзбекча Кирил
  uz-Cyrl-UZ       Uzbek Uzbekistan Cyrillic                 ўзбекча Ўзбекистон Кирил
- uz-Latn          Uzbek                                     o‘zbek
+ uz-Latn          Uzbek Latin                               o‘zbek lotin
  uz-Latn-UZ       Uzbek Uzbekistan Latin                    o‘zbek Oʻzbekiston lotin
  vai              Vai                                       ꕙꔤ
- vai-Latn         Vai                                       Vai
+ vai-Latn         Vai Latin                                 Vai Latn
  vai-Latn-LR      Vai Liberia Latin                         Vai Laibhiya Latn
- vai-Vaii         Vai                                       ꕙꔤ
+ vai-Vaii         Vai Vai                                   ꕙꔤ Vaii
  vai-Vaii-LR      Vai Liberia Vai                           ꕙꔤ ꕞꔤꔫꕩ Vaii
  vi               Vietnamese                                Tiếng Việt
  vi-VN            Vietnamese Vietnam                        Tiếng Việt Việt Nam
@@ -757,12 +759,12 @@ The available locales are:
  zgh              Standard Moroccan Tamazight               ⵜⴰⵎⴰⵣⵉⵖⵜ
  zgh-MA           Standard Moroccan Tamazight Morocco       ⵜⴰⵎⴰⵣⵉⵖⵜ ⵍⵎⵖⵔⵉⴱ
  zh               Chinese                                   中文
- zh-Hans          Chinese                                   中文
+ zh-Hans          Chinese Simplified                        中文 简体
  zh-Hans-CN       Chinese China Simplified                  中文 中国 简体
  zh-Hans-HK       Chinese Hong Kong SAR China Simplified    中文 中国香港特别行政区 简体
  zh-Hans-MO       Chinese Macau SAR China Simplified        中文 中国澳门特别行政区 简体
  zh-Hans-SG       Chinese Singapore Simplified              中文 新加坡 简体
- zh-Hant          Chinese                                   中文
+ zh-Hant          Chinese Traditional                       中文 繁體
  zh-Hant-HK       Chinese Hong Kong SAR China Traditional   中文 中國香港特別行政區 繁體字
  zh-Hant-MO       Chinese Macau SAR China Traditional       中文 中國澳門特別行政區 繁體字
  zh-Hant-TW       Chinese Taiwan Traditional                中文 台灣 繁體
@@ -771,13 +773,16 @@ The available locales are:
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Locale>
-(or L<bug-datetime-locale@rt.cpan.org|mailto:bug-datetime-locale@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-Locale/issues>.
 
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-Locale can be found at L<https://github.com/houseabsolute/DateTime-Locale>.
 
 =head1 AUTHOR
 
@@ -785,9 +790,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dave Rolsky.
+This software is copyright (c) 2003 - 2017 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
